| rotate | R Documentation |
Replaces selected frames with a rotated version in place. For large-angle
transformations. For a small-angle hand-held rock effect, see
wiggle.
rotate(images, degrees, frames = NULL)
images |
an object of class |
degrees |
a number in |
frames |
integer vector of frame indices to duplicate. Defaults to
|
a magick-image object
After each operation a message listing the updated frame sequence is
printed in interactive sessions. Use
stopmotion_verbosity(FALSE) to suppress these messages, or set
options(stopmotion.verbose = FALSE) in your script or
‘.Rprofile’.
dino_dir <- system.file("extdata", package = "stopmotion")
images <- read(dir = dino_dir)
rotate(images = images, degrees = 90, frames = 2L)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.