Learn R Programming

stopmotion (version 0.1.0)

rotate: Rotate images

Description

Replaces selected frames with a rotated version in place. For large-angle transformations. For a small-angle hand-held rock effect, see wiggle.

Usage

rotate(images, degrees, frames = NULL)

Value

a magick-image object

Arguments

images

an object of class magick-image to modify

degrees

a number in [-360, 360] specifying the rotation angle.

frames

integer vector of frame indices to duplicate. Defaults to NULL, which duplicates all frames.

Verbosity

After each operation a message listing the updated frame sequence is printed in interactive sessions. Use stopmotion_verbosity(FALSE) to suppress these messages, or set options(stopmotion.verbose = FALSE) in your script or .Rprofile.

Examples

Run this code
# \donttest{
  dino_dir <- system.file("extdata", package = "stopmotion")
  images <- read(dir = dino_dir)
  rotate(images = images, degrees = 90, frames = 2L)
# }

Run the code above in your browser using DataLab