Learn R Programming

stopmotion (version 0.1.0)

splice: Splice frames into a film

Description

Splice frames into a film

Usage

splice(images, insert, after)

Value

a magick-image object

Arguments

images

an object of class magick-image to modify

insert

an object of class magick-image containing 1 or more images to be inserted.

after

integer scalar (or vector of scalars) giving the frame number(s) after which insert will be inserted. When a vector is supplied the insertions are applied left-to-right, each offset by the cumulative growth of the film from prior insertions.

Verbosity

After each operation a message listing the updated frame sequence is printed in interactive sessions. Use stopmotion_verbosity(FALSE) to suppress these messages, or set options(stopmotion.verbose = FALSE) in your script or .Rprofile.

Examples

Run this code
# \donttest{
  dino_dir <- system.file("extdata", package = "stopmotion")
  images <- read(dir = dino_dir)
  splice(images = images, insert = magick::wizard, after = 1)
# }

Run the code above in your browser using DataLab