| trim | R Documentation |
Removes border pixels from selected frames by detecting the background
colour and trimming uniform edges. Wraps magick::image_trim.
trim(images, fuzz = 0, frames = NULL)
images |
an object of class |
fuzz |
a number in |
frames |
integer vector of frame indices to duplicate. Defaults to
|
a magick-image object
After each operation a message listing the updated frame sequence is
printed in interactive sessions. Use
stopmotion_verbosity(FALSE) to suppress these messages, or set
options(stopmotion.verbose = FALSE) in your script or
‘.Rprofile’.
dino_dir <- system.file("extdata", package = "stopmotion")
images <- read(dir = dino_dir)
trim(images = images)
trim(images = images, fuzz = 10, frames = 1:3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.